@@ -13,5 +13,6 @@ var pipewire_8h =
     [ "pw_get_support_factory", "pipewire_8h.html#af2d5f277271ef9f59827ce7ebf0c4378", null ],
     [ "pw_get_support_interface", "pipewire_8h.html#abadaa5454bbccba79adfa316d725e0a2", null ],
     [ "pw_get_user_name", "pipewire_8h.html#a0b5efe6f38693683c07c4495bfcce6c4", null ],
-    [ "pw_init", "pipewire_8h.html#a06c879b2d800579f4724109054368d99", null ]
+    [ "pw_init", "pipewire_8h.html#a06c879b2d800579f4724109054368d99", null ],
+    [ "pw_release_spa_dbus", "pipewire_8h.html#ad76e718e0df792d89e19d6c984762af0", null ]
 ];
\ No newline at end of file
